function Xs = bif_discrete(func, mu, x1)
% Function to produce the bifurcation diagram for an iterative
% map
% Inputs: func - handle to the iteration function f(x, mu)
%         mu - vector of values of the parameter mu
%         x1 - initial condition for x
% Outputs: Xs - matrix containing the stable fixed/periodic 
%                points for each value of mu
Ntrans = 100;	% iterations to get past transient behaviour
Nplot = 50;	% number of points to plot for each mu
nudge = 1e-6;	% small perturbation to each intial contition
M = length(mu);
Xs = zeros(Nplot, M);
x = x1;  % set x to initial condition
for J = 1:M
   % Do Ntrans iterations with Jth value of mu:
   for K = 1:Ntrans
      x = func(x, mu(J));   
   end
   % Do Nplot iterations, storing results in Jth column of X:
   Xs(1, J) = x;
   for K = 1:Nplot-1
      Xs(K+1, J) = func(Xs(K, J), mu(J));
   end
   % perturb final value slightly for next set of iterations:
   x = Xs(Nplot, J)+nudge;  
end

			
			
	 		