function y = rk4step(dydt, tspan, y0)
% Function for calculating one step of the fourth-order
% Runge-Kutta method on a system dy/dt = f(t, y)
% Inputs: dydt - handle to a function that calculates dy/dt
%         tspan - vector containing the starting and
%                 finishing values of t
%         y0 - initial condition vector
% Outputs: y - solution vector after one RK4 step
delta_t = tspan(2)-tspan(1);
k1 = dydt(tspan(1), y0);
k2 = dydt(0.5*(tspan(1)+tspan(2)), y0+0.5*delta_t*k1);
k3 = dydt(0.5*(tspan(1)+tspan(2)), y0+0.5*delta_t*k2);
k4 = dydt(tspan(2), y0+delta_t*k3);
y = y0+delta_t/6*(k1+2*k2+2*k3+k4);
