function [x, y] = bvp(coeffs, xspan, BCs, N);
% Function to solve a linear second-order BVP
% INPUTS:  coeffs - handle to a function that returns the three
%                   coefficients p(x), q(x) and g(x)
%          xspan - 1x2 vector containing the min and max values
%                  of x
%          BCs - 1x2 vector containing the corresponding values
%                of y
%          N - number of lattice points to use
% OUTPUTS: x - vector of equally spaced x values
%          y - vector of corresponding y values
dx = (xspan(2)-xspan(1))/N;  % Spacing between lattice points
x = (xspan(1):dx:xspan(2))';   % Vector of equally spaced x values
A = zeros(N+1,N+1);          % Initialise A as a matrix of zeros
b = zeros(N+1,1);            % Initialise b as a vector of zeros
A(1,1) = 1;       % Row 1 of matrix A
b(1) = BCs(1);    % Row 1 of vecotr b
for I = 2:N       % Loop through rows 2 to N of A and b
    [p, q, g] = coeffs(x(I));  % Get values of coefficients at x(I)
    A(I, I-1) = 1/dx^2-p/(2*dx);
    A(I, I) = -2/dx^2+q;
    A(I, I+1) = 1/dx^2+p/(2*dx);
    b(I) = g;
end
A(N+1, N+1) = 1;   % Row N+1 of A
b(N+1) = BCs(2);   % Row N+1 of b
y = A\b;           % Solution to matrix equation Ay=b