function [f0, J] = jacobian(func, x)
% Function to evaluate a vector function and find its Jacobian
% INPUTS:  func - handle to the vector function
%          x - argument to vector function
% OUTPUTS: f0 - value of the vector function at x
%          J - value of the Jacobian matrix at x
N = length(x); % length of the vector x         
f0 = func(x);  % evaluate func at x      
dx = 1e-10;    % value of dx to use when calculating the Jacobian
J = zeros(N);  % initialise J as an NxN matrix
for I = 1:N                % loop through columns of J
    x0 = x(I);
    x(I) = x(I)+dx;        % perturb x(I) by dx
    f = func(x);           % evaluate func at perturbed x
    J(:, I) = (f-f0)./dx;  % calculate column I of Jacobian
    x(I) = x0;             % restore x(I) to unperturbed value
end
