function x = newton(func, x, tol, maxits)
% Function to solve a system of equations f(x)=0 by Newton's method
% INPUTS:  x - initial approximation to the solution
%          tol - relative tolerance for testing convergence
%          func - handle to a function that calculates f(x)
%          maxits - maximum number of iterations to carry out
% OUTPUTS: x - solution vector
delta_x = 10*tol*x;
count = 0;
while ~(norm(delta_x, inf)/norm(x, inf) < tol) && count < maxits
    [f, J] = jacobian(func, x);
    delta_x = -J\f;
    x = x+delta_x;
    count = count+1;
end